@@ -150,6 +150,8 @@ int ccl_qual_field2(CCL_bibset bibset, const char *cp, const char *qual_name,
                         value = CCL_BIB1_STR_OR_LIST;
                     if (!ccl_stricmp (value_str, "ag"))
                         value = CCL_BIB1_STR_AUTO_GROUP;
+                    if (!ccl_stricmp (value_str, "sl"))
+                        value = CCL_BIB1_STR_SPLIT_LIST;
                     break;
                 case 't':
                 case 'T':
