@@ -13,7 +13,8 @@
 #endif
 
 #include <string.h>
-#include <yaz/nmem_xml.h>
+#include <yaz/nmem.h>
+#include <yaz/snprintf.h>
 
 char *nmem_strdup(NMEM mem, const char *src)
 {
@@ -141,24 +142,18 @@ void nmem_strsplit_escape2(NMEM nmem, const char *delim, const char *dstr,
     }
 }
 
-#if YAZ_HAVE_XML2
-char *nmem_text_node_cdata(const xmlNode *ptr_cdata, NMEM nmem)
+char *nmem_printf(NMEM nmem, const char *fmt, ...)
 {
-    char *cdata;
-    int len = 0;
-    const xmlNode *ptr;
+    va_list ap;
+    char buf[4096];
+    char *dst;
 
-    for (ptr = ptr_cdata; ptr; ptr = ptr->next)
-        if (ptr->type == XML_TEXT_NODE)
-            len += xmlStrlen(ptr->content);
-    cdata = (char *) nmem_malloc(nmem, len+1);
-    *cdata = '\0';
-    for (ptr = ptr_cdata; ptr; ptr = ptr->next)
-        if (ptr->type == XML_TEXT_NODE)
-            strcat(cdata, (const char *) ptr->content);
-    return cdata;
+    va_start(ap, fmt);
+    yaz_vsnprintf(buf, sizeof(buf), fmt, ap);
+    dst = nmem_strdup(nmem, buf);
+    va_end(ap);
+    return dst;
 }
-#endif
 
 /*
  * Local variables:
