@@ -22,6 +22,7 @@
 #include <yaz/cql.h>
 #include <yaz/ccl.h>
 #include <yaz/sortspec.h>
+#include <yaz/snprintf.h>
 
 #define SORT_STRATEGY_Z3950 0
 #define SORT_STRATEGY_TYPE7 1
@@ -136,12 +137,6 @@ Z_SortKeySpecList *ZOOM_query_get_sortspec(ZOOM_query s)
     return s->sort_strategy == SORT_STRATEGY_Z3950 ? s->sort_spec : 0;
 }
 
-static void cql2pqf_wrbuf_puts(const char *buf, void *client_data)
-{
-    WRBUF wrbuf = (WRBUF) client_data;
-    wrbuf_puts(wrbuf, buf);
-}
-
 const char *ZOOM_query_get_query_string(ZOOM_query s)
 {
     return wrbuf_cstr(s->full_query);
@@ -186,7 +181,7 @@ static char *cql2pqf(ZOOM_connection c, const char *cql)
     else if ((trans = cql_transform_open_fname(cqlfile)) == 0)
     {
         char buf[512];
-        sprintf(buf, "can't open CQL transform file '%.200s': %.200s",
+        yaz_snprintf(buf, sizeof(buf), "can't open CQL transform file '%s': %s",
                 cqlfile, strerror(errno));
         ZOOM_set_error(c, ZOOM_ERROR_CQL_TRANSFORM, buf);
     }
@@ -194,12 +189,12 @@ static char *cql2pqf(ZOOM_connection c, const char *cql)
     {
         WRBUF wrbuf_result = wrbuf_alloc();
         error = cql_transform(trans, cql_parser_result(parser),
-                              cql2pqf_wrbuf_puts, wrbuf_result);
+                              wrbuf_vp_puts, wrbuf_result);
         if (error != 0) {
             char buf[512];
             const char *addinfo;
             error = cql_transform_error(trans, &addinfo);
-            sprintf(buf, "%.200s (addinfo=%.200s)",
+            yaz_snprintf(buf, sizeof(buf), "%s (addinfo=%s)",
                     cql_strerror(error), addinfo);
             ZOOM_set_error(c, ZOOM_ERROR_CQL_TRANSFORM, buf);
         }
